==> jc-1.4.0.tar.gz: javax/print/attribute/HashPrintJobAttributeSet.h <==
// public class javax.print.attribute.HashPrintJobAttributeSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5ac41f29c14cfdf4 javax_print_attribute_HashAttributeSet
// @dep_class 201a9cab92ac6bd3 javax_print_attribute_HashPrintJobAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_HashAttributeSet

#include "javax/print/attribute/HashAttributeSet.h"

#ifndef _JC_javax_print_attribute_HashPrintJobAttributeSet_H_
#define _JC_javax_print_attribute_HashPrintJobAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_PrintJobAttribute$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_refs	_jc_javax_print_attribute_HashPrintJobAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_nonrefs	_jc_javax_print_attribute_HashPrintJobAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$refs	_jc_javax_print_attribute_HashPrintJobAttributeSet$refs;
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$nonrefs	_jc_javax_print_attribute_HashPrintJobAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object	_jc_javax_print_attribute_HashPrintJobAttributeSet$object;

typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$fields_struct	_jc_javax_print_attribute_HashPrintJobAttributeSet$fields_struct;
typedef const struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vmethods	_jc_javax_print_attribute_HashPrintJobAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vtable	_jc_javax_print_attribute_HashPrintJobAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vtype	_jc_javax_print_attribute_HashPrintJobAttributeSet$vtype;

// Class fields structure
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24PrintJobAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_HashPrintJobAttributeSet$fields_struct _jc_javax_print_attribute_HashPrintJobAttributeSet$class_fields;

// Constructors
extern void _jc_javax_print_attribute_HashPrintJobAttributeSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object *);
extern void _jc_javax_print_attribute_HashPrintJobAttributeSet$method$_init$90e8e7bcdc04b332(_jc_env *, struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object *, struct _jc_object *);
extern void _jc_javax_print_attribute_HashPrintJobAttributeSet$method$_init$e5a7e9c8f2357d04(_jc_env *, struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object *, struct _jc_object *);
extern void _jc_javax_print_attribute_HashPrintJobAttributeSet$method$_init$ca237dd9a3fe9b82(_jc_env *, struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object *, struct _jc_object_array *);

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_HashPrintJobAttributeSet$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_HashAttributeSet$vmethods	javax_print_attribute_HashAttributeSet;
	_jc_javax_print_attribute_HashPrintJobAttributeSet$vmethods	javax_print_attribute_HashPrintJobAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_HashPrintJobAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$refs {
    _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_refs	javax_print_attribute_HashPrintJobAttributeSet;
    _jc_javax_print_attribute_HashAttributeSet$sub_refs	javax_print_attribute_HashAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_HashAttributeSet$sub_nonrefs	javax_print_attribute_HashAttributeSet;
    _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_nonrefs	javax_print_attribute_HashPrintJobAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object {
	_jc_javax_print_attribute_HashPrintJobAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_HashPrintJobAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_HashPrintJobAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_HashPrintJobAttributeSet$vtype _jc_javax_print_attribute_HashPrintJobAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_HashPrintJobAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_HashPrintJobAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_HashPrintJobAttributeSet_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/HashPrintJobAttributeSet.h <==
// public class javax.print.attribute.HashPrintJobAttributeSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5ac41f29c14cfdf4 javax_print_attribute_HashAttributeSet
// @dep_class 201a9cab92ac6bd3 javax_print_attribute_HashPrintJobAttributeSet

// header file dependencies
// @dep_header javax_print_attribute_HashAttributeSet

#include "javax/print/attribute/HashAttributeSet.h"

#ifndef _JC_javax_print_attribute_HashPrintJobAttributeSet_H_
#define _JC_javax_print_attribute_HashPrintJobAttributeSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_PrintJobAttribute$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_refs	_jc_javax_print_attribute_HashPrintJobAttributeSet$sub_refs;
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_nonrefs	_jc_javax_print_attribute_HashPrintJobAttributeSet$sub_nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$refs	_jc_javax_print_attribute_HashPrintJobAttributeSet$refs;
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$nonrefs	_jc_javax_print_attribute_HashPrintJobAttributeSet$nonrefs;
typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object	_jc_javax_print_attribute_HashPrintJobAttributeSet$object;

typedef struct _jc_javax_print_attribute_HashPrintJobAttributeSet$fields_struct	_jc_javax_print_attribute_HashPrintJobAttributeSet$fields_struct;
typedef const struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vmethods	_jc_javax_print_attribute_HashPrintJobAttributeSet$vmethods;
typedef const struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vtable	_jc_javax_print_attribute_HashPrintJobAttributeSet$vtable;
typedef const struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vtype	_jc_javax_print_attribute_HashPrintJobAttributeSet$vtype;

// Class fields structure
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24PrintJobAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_HashPrintJobAttributeSet$fields_struct _jc_javax_print_attribute_HashPrintJobAttributeSet$class_fields;

// Constructors
extern void _jc_javax_print_attribute_HashPrintJobAttributeSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintJobAttributeSet$method$_init$90e8e7bcdc04b332(_jc_env *, struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintJobAttributeSet$method$_init$e5a7e9c8f2357d04(_jc_env *, struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_attribute_HashPrintJobAttributeSet$method$_init$ca237dd9a3fe9b82(_jc_env *, struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_HashPrintJobAttributeSet$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vmethods {
};

// Vtable
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_HashAttributeSet$vmethods	javax_print_attribute_HashAttributeSet;
	_jc_javax_print_attribute_HashPrintJobAttributeSet$vmethods	javax_print_attribute_HashPrintJobAttributeSet;
};

// Vtype
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_HashPrintJobAttributeSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$refs {
    _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_refs	javax_print_attribute_HashPrintJobAttributeSet;
    _jc_javax_print_attribute_HashAttributeSet$sub_refs	javax_print_attribute_HashAttributeSet;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_HashAttributeSet$sub_nonrefs	javax_print_attribute_HashAttributeSet;
    _jc_javax_print_attribute_HashPrintJobAttributeSet$sub_nonrefs	javax_print_attribute_HashPrintJobAttributeSet;
};

// Object instance structure
struct _jc_javax_print_attribute_HashPrintJobAttributeSet$object {
	_jc_javax_print_attribute_HashPrintJobAttributeSet$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_HashPrintJobAttributeSet$vtype	*vtype;
	_jc_javax_print_attribute_HashPrintJobAttributeSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_HashPrintJobAttributeSet$vtype _jc_javax_print_attribute_HashPrintJobAttributeSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_HashPrintJobAttributeSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_HashPrintJobAttributeSet$class_object;

#endif	/* _JC_javax_print_attribute_HashPrintJobAttributeSet_H_ */
